using System;
using Gtk;

/*
 *  Gtk# による MessageBox.Show 関数のラップ
 *  Windows 名前空間を参照で利用する人は使ってはいけません。
 */
namespace System.Windows
{
	public enum MessageBoxButton
	{
		Ok,
		OkCancel,
		YesNo,
		YesNoCancel
	};
	
	public enum MessageBoxImage
	{
		DialogAuthentication, //鍵アイコン、Gtk のみ
		Asterisk,             //About でまかなう
		Error,
		Exclamation,          //Warning と共通
		Hand,                 //VisualStudio もエラーアイコン？
		Infomation,
		None,
		Question,
		Stop,
		Warning
	};
	
	/// <summary>
	/// System.Windows.MessageBox のラップ
	/// </summary>
	public class MessageBox
	{
		public static ResponseType Show(string text, string caption, MessageBoxButton type, MessageBoxImage icon)
		{
			Dialog d = new Dialog();
			
			d.Title = caption;
			d.HasSeparator = false;
			d.BorderWidth = 6;
			d.Resizable = false;
			
			HBox h = new HBox();
			h.BorderWidth = 6;
			h.Spacing = 12;
			
			Gtk.Image i;
			switch (icon)
			{
			case MessageBoxImage.Asterisk:
				i = new Image();
				i.SetFromStock(Stock.About, IconSize.Dialog);
				i.SetAlignment(0.5f, 0);
				h.PackStart(i, false, false, 0);
				break;
			case MessageBoxImage.Hand:
			case MessageBoxImage.Error:
				i = new Image();
				i.SetFromStock(Stock.DialogError, IconSize.Dialog);
				i.SetAlignment(0.5f, 0);
				h.PackStart(i, false, false, 0);
				break;
			case MessageBoxImage.Infomation:
				i = new Image();
				i.SetFromStock(Stock.DialogInfo, IconSize.Dialog);
				i.SetAlignment(0.5f, 0);
				h.PackStart(i, false, false, 0);
				break;
			case MessageBoxImage.Question:
				i = new Image();
				i.SetFromStock(Stock.DialogQuestion, IconSize.Dialog);
				i.SetAlignment(0.5f, 0);
				h.PackStart(i, false, false, 0);
				break;
			case MessageBoxImage.Stop:
				i = new Image();
				i.SetFromStock(Stock.Stop, IconSize.Dialog);
				i.SetAlignment(0.5f, 0);
				h.PackStart(i, false, false, 0);
				break;
			case MessageBoxImage.Exclamation:
			case MessageBoxImage.Warning:
				i = new Image();
				i.SetFromStock(Stock.DialogWarning, IconSize.Dialog);
				i.SetAlignment(0.5f, 0);
				h.PackStart(i, false, false, 0);
				break;
			case MessageBoxImage.DialogAuthentication:
				i = new Image();
				i.SetFromStock(Stock.DialogAuthentication, IconSize.Dialog);
				i.SetAlignment(0.5f, 0);
				h.PackStart(i, false, false, 0);
				break;
			}
			
			Label l = new Label(text);
			l.LineWrap = true;
			h.PackEnd(l);
			
			h.ShowAll();
			d.VBox.Add(h);
			switch (type)
			{
			case MessageBoxButton.Ok:
				d.AddButton(Stock.Ok, ResponseType.Ok);
				break;
			case MessageBoxButton.OkCancel:
				d.AddButton(Stock.Cancel, ResponseType.Cancel);
				d.AddButton(Stock.Ok, ResponseType.Ok);
				break;
			case MessageBoxButton.YesNo:
				d.AddButton(Stock.Yes, ResponseType.Yes);
				d.AddButton(Stock.No, ResponseType.No);
				break;
			case MessageBoxButton.YesNoCancel:
				d.AddButton(Stock.Yes, ResponseType.Yes);
				d.AddButton(Stock.No, ResponseType.No);
				d.AddButton(Stock.Cancel, ResponseType.Cancel);
				break;
			}
			int result = d.Run();
			d.Destroy();
			return (ResponseType)result;
		}
		
		public static ResponseType Show(string text, string caption, MessageBoxButton type)
		{
			Dialog d = new Dialog();
			
			d.Title = caption;
			d.HasSeparator = false;
			d.BorderWidth = 6;
			d.Resizable = false;
			
			HBox h = new HBox();
			h.BorderWidth = 6;
			h.Spacing = 12;
			
			Label l = new Label(text);
			l.LineWrap = true;
			h.PackEnd(l);
			
			h.ShowAll();
			d.VBox.Add(h);
			switch (type)
			{
			case MessageBoxButton.Ok:
				d.AddButton(Stock.Ok, ResponseType.Ok);
				break;
			case MessageBoxButton.OkCancel:
				d.AddButton(Stock.Cancel, ResponseType.Cancel);
				d.AddButton(Stock.Ok, ResponseType.Ok);
				break;
			case MessageBoxButton.YesNo:
				d.AddButton(Stock.Yes, ResponseType.Yes);
				d.AddButton(Stock.No, ResponseType.No);
				break;
			}
			int result = d.Run();
			d.Destroy();
			return (ResponseType)result;
		}
		
		public static ResponseType Show(string text, string caption)
		{
			Dialog d = new Dialog();
			
			d.Title = caption;
			d.HasSeparator = false;
			d.BorderWidth = 6;
			d.Resizable = false;
			
			HBox h = new HBox();
			h.BorderWidth = 6;
			h.Spacing = 12;
			
			Label l = new Label(text);
			l.LineWrap = true;
			h.PackEnd(l);
			
			h.ShowAll();
			d.VBox.Add(h);

			d.AddButton(Stock.Ok, ResponseType.Ok);

			int result = d.Run();
			d.Destroy();
			return (ResponseType)result;
		}
		
		public static ResponseType Show(string message)
		{
			MessageDialog d = new MessageDialog(
	            null,//(Window)this,
	            Gtk.DialogFlags.Modal,
	            Gtk.MessageType.Other,
	            Gtk.ButtonsType.Ok,
	            message);
	        int result = d.Run();
			d.Destroy();
			return (ResponseType)result;
		}
	}
}
